@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: safe
-version: 0.3.2
-id: safe-0.3.2-4fdcb6ce1bedc64a77ccf85aa837e21f
+version: 0.3.3
+id: safe-0.3.3-3fc1838ea15326253992757aa508c0f2
 
 license: BSD3
 copyright: Neil Mitchell 2007-2011
@@ -22,19 +22,19 @@ exposed: True
 exposed-modules: Safe Safe.Foldable
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/safe-0.3.2
-library-dirs: /usr/local/lib/ghc/safe-0.3.2
-hs-libraries: HSsafe-0.3.2
+import-dirs: /usr/local/lib/ghc/safe-0.3.3
+library-dirs: /usr/local/lib/ghc/safe-0.3.3
+hs-libraries: HSsafe-0.3.3
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
+depends: base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-safe-0.3.2/html/safe.haddock
-haddock-html: /usr/local/share/doc/hs-safe-0.3.2/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-safe-0.3.3/html/safe.haddock
+haddock-html: /usr/local/share/doc/hs-safe-0.3.3/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
